#ifndef NT2_INCLUDE_FUNCTIONS_MUL_I_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MUL_I_HPP_INCLUDED

#include <nt2/complex/include/functions/mul_i.hpp>

#endif
